# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Perl-MinimumVersion
Version:	1.40
Release:	9.%{__distinit}%{__distvers}
Summary:	Find a minimum required version of perl for Perl code
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Perl-MinimumVersion
Source0:	https://cpan.metacpan.org/modules/by-module/Perl/Perl-MinimumVersion-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(List::Util) >= 1.20
BuildRequires:	perl(Params::Util) >= 0.25
BuildRequires:	perl(PPI) >= 1.215
BuildRequires:	perl(PPI::Util)
BuildRequires:	perl(PPIx::Regexp) >= 0.033
BuildRequires:	perl(PPIx::Utils)
BuildRequires:	perl(strict)
BuildRequires:	perl(version) >= 0.76
BuildRequires:	perl(warnings)
# Script Runtime
BuildRequires:	perl(File::Find::Rule)
BuildRequires:	perl(File::Find::Rule::Perl)
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(Test::More) >= 0.47
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
Find a minimum required version of perl for Perl code.

%prep
%setup -q -n Perl-MinimumVersion-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README
%{_bindir}/perlver
%{perl_vendorlib}/Perl/
%{_mandir}/man1/perlver.1*
%{_mandir}/man3/Perl::MinimumVersion.3*

%changelog
* Mon Jul 10 2023 Paul Howarth <paul@city-fan.org> - 1.40-9
- Use SPDX-format license tag

* Thu Apr 22 2021 Paul Howarth <paul@city-fan.org> - 1.40-1
- Update to 1.40
  - Features enabled via the 'experimental' pragma are now recognized (GH#5)
  - Depend on PPIx::Utils instead of Perl::Critic::Utils (GH#6)
  - Recognize several new features and their minimum required Perl versions
    (GH#10, GH#20): 'say', 'smartmatch', 'postderef', 'postderef_qq',
    'signatures', 'refaliasing', 'bitwise', 'declared_refs', 'isa', 'indirect'
- Use %%license unconditionally

* Sat Oct  5 2019 Paul Howarth <paul@city-fan.org> - 1.38-23
- Bump List::Util version requirement from 1.18 to 1.20

* Sun Jun  9 2019 Paul Howarth <paul@city-fan.org> - 1.38-22
- Perl 5.30 rebuild

* Tue Jan 30 2018 Paul Howarth <paul@city-fan.org> - 1.38-15
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with List::Util < 1.18

* Wed Sep 21 2016 Paul Howarth <paul@city-fan.org> - 1.38-11
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Sep 16 2014 Paul Howarth <paul@city-fan.org> - 1.38-4
- Perl 5.20 rebuild

* Tue Sep  9 2014 Paul Howarth <paul@city-fan.org> - 1.38-1
- Update to 1.38
  - The doc for Perl::MinimumVersion now mentions perlver in both the
    DESCRIPTION and SEE ALSO sections (CPAN RT#98262)
  - Added mention of Perl::MinimumVersion::Fast to SEE ALSO
- Use %%license where possible
- Update patch to support building with List::Util 1.18 for Fedora < 11

* Sun May 11 2014 Paul Howarth <paul@city-fan.org> - 1.37-1
- Update to 1.37
  - Removed the check for "stacked labels" that I added in 1.36, as it appears
    that I misinterpreted what the 5.14 change was, and broke at least one dist
  - The way I was comparing versions in one of the new tests in 1.36 wasn't
    portable across old versions of Perl (CPAN RT#95528)

* Sat May 10 2014 Paul Howarth <paul@city-fan.org> - 1.36-1
- Update to 1.36
  - CHECK block requires 5.6.2
  - UNITCHECK block requires 5.10.0
  - Stacked labels on the same statement requires 5.14.0
- Add patch to compare versions in a way that works on old perls too
  (CPAN RT#95528)

* Fri May  2 2014 Paul Howarth <paul@city-fan.org> - 1.35-1
- Update to 1.35
  - 'state' requires perl 5.10.0, even if you don't also see
     "use feature 'state'", because you can also write "use 5.010" to enable
     'state' (CPAN RT#67626)
  - Dropped the rule that said "use base 'Exporter'" should make a dependency
    on Perl 5.008+ (CPAN RT#89173)
  - Improved the fix for CPAN RT#95023

* Fri Apr 25 2014 Paul Howarth <paul@city-fan.org> - 1.34-1
- Update to 1.34
  - The perlver script wasn't getting installed, because it's in a script/
    directory (CPAN RT#95023)
  - t/02_main.t was failing on older versions of perl, because a min version is
    getting reported as '5.01301' on Perl 5.010 and later, but as '5.013010' on
    earlier Perls (CPAN RT#95023)
- Drop upstreamed patches
- Update patch to support building with List::Util 1.18 for Fedora < 11

* Thu Apr 24 2014 Paul Howarth <paul@city-fan.org> - 1.33-1
- Update to 1.33
  - Internals::SvREADONLY requires perl 5.8.0
  - Handle features upto lexical_subs, which requires 5.18.0:
    state, switch, unicode_strings, unicode_eval, evalbytes, current_sub,
    array_base, fc, lexical_subs
  - deprecate.pm requires perl 5.12
  - Require new version of PPIx::Regexp
  - Detect while(readdir $dh)
  - Switched to Dist::Zilla
  - Added required versions of modules when use'ing them
  - Reformatted Changes as per CPAN::Changes::Spec
- This release by NEILB -> update source URL
- Add patch to get perlver script installed
- Add patch to fix test suite with perl 5.8 (CPAN RT#95023)
- Add patch to support building with List::Util 1.18 for Fedora < 11
- Drop %%defattr, redundant since rpm 4.4
- Classify buildreqs by usage

* Thu Jan 17 2013 Paul Howarth <paul@city-fan.org> - 1.32-1
- Update to 1.32
  - require new version of PPIx::Regexp
  - skip sub named keys/each/values in _each_argument() (CPAN RT#82718)
  - detect open with reference to scalar

* Wed Dec  5 2012 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31
  - sort $subref requires perl 5.6
- Drop version typo patch, no longer needed

* Thu Nov 29 2012 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.30
  - 'each %% { $foo }' incorrectly required perl 5.14 (CPAN RT#81505)
  - 02_main.t fails in rare cases (CPAN RT#81487)
- Drop upstreamed patch for CPAN RT#81487
- Add patch to fix typo in version number for Perl::MinimumVersion::Reason
- This release by CHORNY -> update source URL

* Tue Nov 27 2012 Paul Howarth <paul@city-fan.org> - 1.29-1
- Update to 1.29
  - fix for "Use of uninitialized value in null operation"
  - add test for "utf8::is_utf" 5.8.1 special case
  - recognize all versions in "use feature" bundle
  - support regexes
  - detect changes in each/keys/values in 5.12 and 5.14
  - 2-arg binmode
  - postfix when
  - exists(&sub)
  - _bugfix_magic_errno will return element
  - add 'encoding' to 5.8 pragmas
  - private methods _set_checks2skip and _set_collect_all_reasons for
    Perl::Critic::Policy::Compatibility::PerlMinimumVersionAndWhy
  - temp file with open requires 5.8
- BR: perl(PPIx::Regexp) ≥ 0.028
- Add patch to work around version comparison issues on some older perls

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 1.28-6
- Perl 5.16 post-bootstrap rebuild

* Fri Jul 13 2012 Paul Howarth <paul@city-fan.org> - 1.28-5
- BR: perl(Carp), perl(Cwd), perl(Exporter), perl(File::Path),
  perl(File::Spec::Functions) and perl(PPI::Util)

* Fri Mar  2 2012 Paul Howarth <paul@city-fan.org> - 1.28-3
- Downgrade List::Util version requirement to 1.14 to support FC-3 build
- Use DESTDIR rather than PERL_INSTALL_ROOT
- Don't need to remove empty directories from buildroot

* Tue Jun 28 2011 Paul Howarth <paul@city-fan.org> - 1.28-2
- Rebuild for perl 5.14.1 in Rawhide
- Add support for perl_bootstrap macro for mass rebuilds
- Run the release tests too
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Mar  2 2011 Paul Howarth <paul@city-fan.org> - 1.28-1
- Update to 1.28
  - the ->isa in the 5.10 operator and magic variable tests were back to front,
    breaking both
  - magic variable rules now check using ->symbol method instead of ->content
    so that $+{foo} are correctly treated like %+
  - removed -w from tests to allow testing with Tainting on

* Sat Feb 26 2011 Paul Howarth <paul@city-fan.org> - 1.27-1
- Update to 1.27
  - updating to Module::Install::DSL 1.00
  - updating copyright year
  - fix detection of binary numbers
  - add check for variables added in 5.5
  - correct detection of different cases of '...'
  - detection of bareword that ends with double colon

* Thu Jul 22 2010 Paul Howarth <paul@city-fan.org> - 1.26-1
- Update to 1.26
  - detect "package NAME VERSION" in 5.12
  - detect "..." (yada yada yada) in 5.12
  - detect "use feature ':5.12';" in 5.12
- This release by ADAMK -> update source URL

* Mon Jul 19 2010 Paul Howarth <paul@city-fan.org> - 1.25-1
- Update to 1.25
  - error in minimum_syntax_reason discovered by perl 5.12
- This release by CHORNY -> update source URL
- Drop svn patch, no longer needed

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 1.24-3
- Rebuild for perl 5.12.1 in Rawhide

* Mon May 10 2010 Paul Howarth <paul@city-fan.org> - 1.24-2
- Update from svn for issues with 5.12.0 version objects
- Fix dist tag for RHEL-6 Beta

* Fri Jan 22 2010 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
  - the --blame option now works in the perlver script
  - the --blame output now prints actually shows which file
  - add first experimental version of the new _reason API
  - capture limitations in P:MV:Reason
  - add 5.8 dependency for "use Carp version ()"
  - module Errno requires perl 5.5
  - PPI is no longer compatible with perl 5.5, so P::MV can also depend on 5.6
  - bump File::Find::Rule dependency to 0.32 because we break with 0.31
- New upstream maintainer -> new source URL

* Thu Nov 26 2009 Paul Howarth <paul@city-fan.org> - 1.22-1
- Update to 1.22
  - negative length in 'splice' requires perl 5.5
  - 'mkdir' with one argument requires perl 5.6
  - 'substr' will not be checked if it is a method name
  - better tests and fix for 3-arg 'open'

* Tue Nov 24 2009 Paul Howarth <paul@city-fan.org> - 1.21-1
- Update to 1.21
  - add 'bytes' to 5.6 pragma
  - add support for "version numbers" like "v1.1.1"
  - steal argument counting code from Perl::Critic
  - reimplement _three_argument_open, more tests
  - now check for 3-arg open is working
  - check 4-arg substr that requires perl 5.5
  - postfix foreach requires perl 5.004.05
  - Scalar::Util::weaken requires perl 5.006
  - P::MV itself found imcompatibility in 02_main.t with 5.5
- New maintainer -> new source URL
- BR: perl(Perl::Critic::Utils) >= 1.104

* Mon Apr  6 2009 Paul Howarth <paul@city-fan.org> - 1.20-1
- Update to 1.20
- BR: perl(Test::CPAN::Meta) >= 0.12
- Update to SLES-compatible dist tag macros

* Mon Sep 15 2008 Paul Howarth <paul@city-fan.org> - 1.19-1
- Update to 1.19
- Update version requirements for File::Find::Rule (0.30), PPI (1.201)
- Add buildreq perl(ExtUtils::MakeMaker)
- Add buildreq perl(File::Find::Rule::Perl) >= 1.04
- Add buildreq perl(Params::Util), unversioned for old distribution support
- Add buildreq perl(Test::MinimumVersion) - yes, a circular dep :-(

* Mon Sep  1 2008 Paul Howarth <paul@city-fan.org> - 1.18-2
- Import from Fedora
- Drop version requirement for perl(List::Util) to support building on
  older distributions

* Mon Aug 25 2008 Ralf Corsépius <corsepiu@fedoraproject.org> - 1.18-1
- Upstream update

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.15-5
- Rebuild for perl 5.10 (again)

* Sun Jan 13 2008 Tom "spot" Callaway <tcallawa@redhat.com> 0.15-4
- correct List::Util version, perl 5.10.0 has 1.19

* Fri Jan 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> 0.15-3
- rebuild for new perl

* Thu Jan 10 2008 Ralf Corsépius <rc040203@freenet.de> - 0.15.2
- Use unversioned BR: perl(version) to circumvent perl vs. rpm versioning 
  conflicts

* Tue Nov 20 2007 Ralf Corsépius <rc040203@freenet.de> - 0.15-1
- Initial version
